@@ -5,12 +5,12 @@
 
 //===================================================================
 // Read configuration
-function ReadConf($group){
+function ReadConf($group=''){
 
 	global $locsep,$lang,$redbuild,$modgroup,$disc,$fahrtmp;
 	global $comms,$mod,$backend,$dbhost,$dbname,$dbuser,$dbpass,$retire;
 	global $timeout,$ignoredvlans,$useivl,$cpua,$mema,$tmpa,$trfa,$trfw;
-	global $pause,$latw,$rrdcmd,$nedipath,$rrdstep;
+	global $poew,$pause,$latw,$rrdcmd,$nedipath,$rrdstep;
 	global $cacticli,$cactiuser,$cactipass,$cactidb,$cactihost,$cactiurl;
 	global $guiauth,$radsrv, $ldapsrv, $ldapmap;
 
@@ -45,13 +45,14 @@ function ReadConf($group){
 			}
 			elseif ($v[0] == "backend")	{$backend = $v[1];}
 			elseif ($v[0] == "dbhost")	{$dbhost  = $v[1];}
-			elseif ($v[0] == "dbname")	{$dbname  = $v[1];}
+			elseif ($v[0] == "dbname")	{$dbname  = isset($_SESSION['snap'])?$_SESSION['snap']:$v[1];}
 			elseif ($v[0] == "dbuser")	{$dbuser  = $v[1];}
 			elseif ($v[0] == "dbpass")	{$dbpass  = $v[1];}
 
 			elseif ($v[0] == "cpu-alert")	{$cpua = $v[1];}
 			elseif ($v[0] == "mem-alert")	{$mema = $v[1];}
 			elseif ($v[0] == "temp-alert")	{$tmpa = $v[1];}
+			elseif ($v[0] == "poe-warn"){	$poew  = $v[1];}
 			elseif ($v[0] == "traf-alert")	{$trfa = $v[1];}
 			elseif ($v[0] == "traf-warn")	{$trfw = $v[1];}
 
@@ -87,13 +88,14 @@ function ReadConf($group){
 
 //===================================================================
 // Avoid directory traversal attacks (../ or ..\)
-// Avoid condition exclusion (e.g. attacking viewdev) with mysql comment --
+// Remove <script> tags
+//       Avoid condition exclusion (e.g. attacking viewdev) with mysql comment --
 // Recursive because array elements can be array as well
 function sanitize( $arr ){
 	if ( is_array($arr) ){
 		return array_map( 'sanitize', $arr );
 	}
-	return preg_replace( "/\.\.[\/]|--/","", $arr );
+	return preg_replace( "/\.\.\/|<(\/)?script>|javascript/i","", $arr );
 }
 
 //===================================================================
@@ -103,7 +105,7 @@ function hex2ip($hip){
 }
 
 //===================================================================
-// Return from IP address as hex
+// Return IP address as hex
 function ip2hex($ip){
 	$i =  explode('.', str_replace( "*", "", $ip ) );
 	return  sprintf("%02x%02x%02x%02x",$i[0],$i[1],$i[2],$i[3]);
@@ -125,11 +127,11 @@ function ipinv($ip){
 
 //===================================================================
 // convert netmask to various formats and check whether it's valid.
-function Masker($nm){
+function Masker($in){
 
-	if(preg_match("/^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/",$nm) ){
-		$mask = $nm;
-		list($n1,$n2,$n3,$n4) = explode('.', $nm);
+	if(preg_match("/^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/",$in) ){
+		$mask = $in;
+		list($n1,$n2,$n3,$n4) = explode('.', $in);
 		$bits = str_pad(decbin($n1),8,0,STR_PAD_LEFT) .
 			str_pad(decbin($n2),8,0,STR_PAD_LEFT) .
 			str_pad(decbin($n3),8,0,STR_PAD_LEFT) .
@@ -137,24 +139,29 @@ function Masker($nm){
 		#$bits = str_pad(decbin($n1) . decbin($n2) . decbin($n3) . decbin($n4),32,0);
 		$nbit = count_chars($bits);
 		$pfix = $nbit[49];										// the 49th char is "1"...
-	}elseif(preg_match("/^[-]|\d{3,10}$/",$nm ) ){
-		$nm   = sprintf("%u",$nm);
-		$mask = long2ip($nm);
-		$bits = base_convert($nm, 10, 2);
+		$dec  = ip2long($in);
+	}elseif(preg_match("/^[-]|\d{3,10}$/",$in ) ){
+		if( is_int($in) ){
+			$in = sprintf("%u",$in);
+		}
+		$mask = long2ip($in);
+		$bits = base_convert($in, 10, 2);
 		$nbit = count_chars($bits);
 		$pfix = $nbit[49];
-	}elseif(preg_match("/^\d{1,2}$/",$nm) ){
+		$dec  = $in;
+	}elseif(preg_match("/^\d{1,2}$/",$in) ){
 		#shift left of 255.255.255.255 will be 255.255.255.255.0! Trim after SHL (Vasily)
-		#$bits = base_convert(sprintf("%u",0xffffffff << (32 - $nm) ),10,2);
-		$bits = base_convert(sprintf("%u",0xffffffff & (0xffffffff << (32 - $nm)) ),10,2);
+		#$bits = base_convert(sprintf("%u",0xffffffff << (32 - $in) ),10,2);
+		$bits = base_convert(sprintf("%u",0xffffffff & (0xffffffff << (32 - $in)) ),10,2);
 		$mask = bindec(substr($bits, 0,8)).".".bindec(substr($bits, 8,8)).".".bindec(substr($bits, 16,8)).".".bindec(substr($bits, 24,8));
-		$pfix = $nm;
+		$pfix = $in;
+		$dec  = 0xffffffff << (32 - $in);
 	}
 	$bin	= preg_replace( "/(\d{8})/", ".\$1", $bits );
-	if(preg_match("/01/",$bits) ){
-		return array($nm,'Illegal Mask',$bin);
+	if(strstr($bits,'01') ){
+		return array($pfix,'Illegal Mask',$bin,$dec);
 	}else{
-		return array($pfix,$mask,$bin);	
+		return array($pfix,$mask,$bin,$dec);	
 	}
 }
 
@@ -200,38 +207,6 @@ function Agecol($fs, $ls,$row){
         return array("$g$f$d","$l$g$d");
 }
 
-//===================================================================
-// Generate column headers with sorting (obsolete soon)
-function ColHead($n,$w=0){
-
-	global $ord,$cols,$altlbl,$srtlbl;
-
-	$wi="nowrap ";
-	if( isset($_GET['xls']) ){
-		echo "<th>$cols[$n]</th>";
-	}else{
-		if($w){
-			$wi .="width=$w";
-		}
-
-		if (!$ord){
-			echo "<th $wi>$cols[$n]<a href=?$_SERVER[QUERY_STRING]&ord=$n+desc><img src=img/dwn.png title=\"Sort by $n\"></a></th>";
-		}elseif($ord == $n){
-			echo "<th $wi class=mrn>$cols[$n] <a href=?";
-			echo preg_replace('/&ord=(.*)/',"&ord=$n+desc",$_SERVER['QUERY_STRING']);
-			echo "><img src=img/up.png title=\"$srtlbl\"></a></th>";
-		}elseif($ord == "$n desc"){
-			echo "<th $wi class=olv>$cols[$n] <a href=?";
-			echo preg_replace('/&ord=(.*)/',"&ord=$n",$_SERVER['QUERY_STRING']);
-			echo "><img src=img/dwn.png title=\"$altlbl $srtlbl\"></a></th>";
-		}else{
-			echo "<th $wi>$cols[$n] <a href=?";
-			echo preg_replace('/&ord=(.*)/',"&ord=$n+desc",$_SERVER['QUERY_STRING']);
-			echo "><img src=img/dwn.png title=\"$srtlbl $n\"></a></th>";
-		}
-	}
-}
-
 //===================================================================
 // Generate html select box
 function selectbox($type,$sel=""){
@@ -239,16 +214,72 @@ function selectbox($type,$sel=""){
 	global $cndlbl;
 	
 	if($type == "oper"){
-		$options = array("regexp"=>"regexp","not regexp"=>"!regexp","regexpCI"=>"reg CI","not regexpCI"=>"!reg CI","like"=>"like",">"=>">","="=>"=","!="=>"!=",">="=>">=","<"=>"<","&"=>"and","||"=>"or","COL IS"=>"is","COL IS NOT"=>"is not");
+		$options = array("regexp"=>"regexp","not regexp"=>"!regexp","like"=>"like",">"=>">","="=>"=","!="=>"!=",">="=>">=","<"=>"<","&"=>"and","|"=>"or");
 	}elseif($type == "comop"){
 		$options = array(""=>"$cndlbl A","AND"=>"A and B","OR"=>"A or B",">"=>"colA > colB","="=>"colA = colB","!="=>"colA != colB","<"=>"colA < colB");
 	}elseif($type == "limit"){
 		$options = array("5"=>"5","10"=>"10","20"=>"20","50"=>"50","100"=>"100","200"=>"200","500"=>"500","1000"=>"1000","2000"=>"2000","0"=>"none!");
 	}
 	foreach ($options as $key => $txt){
-	       $selopt = ($sel == "$key")?"selected":"";
-	       echo "<option value=\"$key\" $selopt >$txt\n";
+	       $selopt = ($sel == "$key")?" selected":"";
+	       echo "<option value=\"$key\"$selopt>$txt\n";
 	}
+	#TODO add this and opening tag to function? echo "</select>\n" or just return array, which can be used for sanity checks?
+}
+
+//===================================================================
+// Generate filter controls TODO implement!
+function FltCtrl($in,$op,$st,$co){
+
+	global $self, $selfi, $modgroup, $cndlbl, $cmblbl, $calendar, $cols, $col;
+?>
+<form method="get" name="list" action="<?= $self ?>.php">
+<table class="content"><tr class="<?= $modgroup[$self] ?>1">
+<th width="50"><a href="<?= $self ?>.php"><img src="img/32/<?= $selfi ?>.png"></a></th>
+<th valign="top"><?= $cndlbl ?> A<p>
+<select size="1" name="ina">
+<?php
+foreach ($cols as $k => $v){
+       echo "<option value=\"$k\"".( ($ina == $k)?" selected":"").">$v\n";
+}
+?>
+</select>
+<select size="1" name="opa">
+<?php selectbox("oper",$opa) ?>
+</select><p>
+<?PHP if($calendar){echo "<a href=\"javascript:show_calendar('list.stb');\"><img src=\"img/16/date.png\"></a>\n";} ?>
+<input type="text" name="sta" value="<?= $sta ?>" size="20">
+</th>
+<th valign="top"><?= $cmblbl ?><p>
+<select size="1" name="cop">
+<?php selectbox("comop",$cop) ?>
+</select>
+</th>
+<th valign="top"><?= $cndlbl ?> B<p>
+<select size="1" name="inb">
+<?php
+foreach ($cols as $k => $v){
+       echo "<option value=\"$k\"".( ($inb == $k)?" selected":"").">$v\n";
+}
+?>
+</select>
+<select size="1" name="opb">
+<?php selectbox("oper",$opb) ?>
+</select><p>
+<?PHP if($calendar){echo "<a href=\"javascript:show_calendar('list.stb');\"><img src=\"img/16/date.png\"></a>\n";} ?>
+<input type="text" name="stb" value="<?= $stb ?>" size="20">
+</th>
+<th valign="top"><?= $collbl ?><p>
+<select multiple name="col[]" size="4">
+<?php
+foreach ($cols as $k => $v){
+       echo "<option value=\"$k\"".((in_array($k,$col))?"selected":"").">$v\n";
+}
+?>
+
+</select>
+</th>
+<?PHP
 }
 
 //===================================================================
@@ -261,76 +292,98 @@ function ConHead($ina, $opa, $sta, $cop="", $inb="", $opb="", $stb=""){
 	#	echo "<h3>$fltlbl: $nonlbl</h3>";
 	}else{
 		if($cop == ""){ 
-			echo "<h3>$fltlbl: $ina $opa \"$sta\"</h3>";
+			echo "<h3>$fltlbl: $ina $opa \"$sta\"</h3>\n";
 		}elseif($cop =="AND" or $cop =="OR"){ 
-			echo "<h3>$fltlbl: $ina $opa \"$sta\" $cop $inb $opb \"$stb\"</h3>";
+			echo "<h3>$fltlbl: $ina $opa \"$sta\" $cop $inb $opb \"$stb\"</h3>\n";
 		}else{
-			echo "<h3>$fltlbl: $ina $cop $inb</h3>";
+			echo "<h3>$fltlbl: $ina $cop $inb</h3>\n";
 		}
 	}
 }
 
 //===================================================================
-// Generate table row
-function TblHead($stl,$srt = 0){
+// Generate table header
+// Opt	Bgcolor, column mode: 2 or 3=use all, 0 or 3=no sorting (1 shows selected columns with sorting arrow)
+// Keys BL=blank, IG=ignored, NS=no-sort
+function TblHead($bkg,$mode = 0){
 
 	global $ord,$cols,$col,$altlbl,$srtlbl;
 
-	echo "<table class=\"content\"><tr class=\"$stl\">";
+	if( isset($_GET['xls']) ){
+		echo "<table><tr>";
+	}else{
+		echo "<table class=\"content\"><tr>";
+	}
 
-	foreach($col as $n){
-		if( !array_key_exists($n,$cols) or isset($_GET['xls']) or !$srt){
-			echo "<th>$cols[$n]</th>";
-		}else{
-			if (!$ord){
-				echo "<th nowrap>$cols[$n]<a href=?$_SERVER[QUERY_STRING]&ord=$n+desc><img src=img/dwn.png title=\"Sort by $n\"></a></th>";
-			}elseif($ord == $n){
-				echo "<th nowrap class=mrn>$cols[$n] <a href=?";
-				echo preg_replace('/&ord=(.*)/',"&ord=$n+desc",$_SERVER['QUERY_STRING']);
-				echo "><img src=img/up.png title=\"$srtlbl\"></a></th>";
-			}elseif($ord == "$n desc"){
-				echo "<th nowrap class=olv>$cols[$n] <a href=?";
-				echo preg_replace('/&ord=(.*)/',"&ord=$n",$_SERVER['QUERY_STRING']);
-				echo "><img src=img/dwn.png title=\"$altlbl $srtlbl\"></a></th>";
+	if($mode == 2 or $mode == 3){
+		$mycol = array_keys($cols);
+	}else{
+		$mycol = $col;
+	}
+	foreach( $mycol as $n ){
+		if( !preg_match('/IG$/',$n) ){
+			if( preg_match('/BL$/',$n) ){
+				echo "<th class=\"$bkg\">&nbsp;</th>";
+			}elseif( isset($_GET['xls']) or preg_match('/NS$/',$n) or $mode == 3 or !$mode ){
+				echo "<th class=\"$bkg\">$cols[$n]</th>";
+			}elseif( !array_key_exists($n,$cols) ){
+				echo "<th class=\"$bkg\">$n</th>";
 			}else{
-				echo "<th nowrap>$cols[$n] <a href=?";
-				echo preg_replace('/&ord=(.*)/',"&ord=$n+desc",$_SERVER['QUERY_STRING']);
-				echo "><img src=img/dwn.png title=\"$srtlbl $n\"></a></th>";
+				if( !$ord ){
+					echo "<th nowrap class=\"$bkg\">$cols[$n]<a href=\"?$_SERVER[QUERY_STRING]&ord=$n+desc\"><img src=img/dwn.png title=\"Sort by $n\"></a></th>\n";
+				}elseif($ord == $n){
+					echo "<th nowrap class=\"$bkg mrn\">$cols[$n] <a href=\"?";
+					echo preg_replace('/&ord=(.*)/',"",$_SERVER['QUERY_STRING']);
+					echo "&ord=$n+desc\"><img src=\"img/up.png\" title=\"$srtlbl\"></a></th>\n";
+				}elseif($ord == "$n desc"){
+					echo "<th nowrap class=\"$bkg mrn\">$cols[$n] <a href=\"?";
+					echo preg_replace('/&ord=(.*)/',"",$_SERVER['QUERY_STRING']);
+					echo "&ord=$n\"><img src=\"img/dwn.png\" title=\"$altlbl $srtlbl\"></a></th>\n";
+				}else{
+					echo "<th nowrap class=\"$bkg\">$cols[$n] <a href=\"?";
+					echo preg_replace('/&ord=(.*)/',"",$_SERVER['QUERY_STRING']);
+					echo "&ord=$n+desc\"><img src=\"img/dwn.png\" title=\"$srtlbl $n\"></a></th>\n";
+				}
 			}
 		}
 	}
-
 	echo "</tr>\n";
 }
 
 //===================================================================
 // Generate table row
-function TblRow($over=0){
+function TblRow($bg,$static=0){
 
-	global $bg;
 
-	if($over and !isset($_GET['print']) and !isset($_GET['xls']) ){
-		echo "<tr class=\"$bg\" onmouseover=\"this.className='imga'\" onmouseout=\"this.className='$bg'\">";
-	}else{
+	if( isset($_GET['xls']) ){
+		echo "<tr>";
+	}elseif($static){
 		echo "<tr class=\"$bg\">";
+	}elseif(isset($_GET['print']) ){
+		echo "<tr class=\"$bg\" onclick=\"this.className='noti'\" ondblclick=\"this.className='$bg'\">";
+	}else{
+		echo "<tr class=\"$bg\" onmouseover=\"this.className='imga'\" onmouseout=\"this.className='$bg'\">";
 	}
 }
 
 //===================================================================
 // Generate table cell
-function TblCell($val,$href="",$class="",$img=""){
+function TblCell($val="",$href="",$fmt="",$img="",$typ=""){
+#TODO clean code!
+	$cval = ( !isset($_GET['print']) and !isset($_GET['xls']) and $href )?"<a href=\"$href\">$val</a>":$val;
+	$cimg = ( !(isset($_GET['print']) and !strstr($typ,"-img") ) and !isset($_GET['xls']) and $img )?$img:"";
 
-	$cval = ( !isset($_GET['print']) and !isset($_GET['xls']) and $href)?"<a href=\"$href\">$val</a>":$val;
-	$cimg = ( !isset($_GET['print']) and !isset($_GET['xls']) and $img)?$img:"";
-	$ccla = ($class)?"class=\"$class\"":"";
-
-	echo "<td $ccla>$cimg $cval</td>";
+	if( strstr($typ,"th") ){
+		echo "<th $fmt>$cimg$cval</th>";
+	}else{
+		echo "<td $fmt>$cimg$cval</td>";
+	}
 }
 
 //===================================================================
-// Generate coloured bar for html
-// mode determines color (threshold, if numeric)
-// style si=small icon, ms=medium shape, li=large icon (default)
+// Generate coloured bar graph element
+// mode determines color (used as threshold, if numeric)
+// style si=small icon, mi=medium icon, ms=medium shape, li=large icon (default)
 function Bar($val=1,$mode=0,$style="",$title=""){
 
 	$tit   = $val;
@@ -410,15 +463,30 @@ function Bar($val=1,$mode=0,$style="",$title=""){
 
 //===================================================================
 // Return network type
-function Nettype($nt){
+function Nettype($ip,$ip6=""){
+echo $ipv6;
+	#if ($ip == "0.0.0.0"){$img = "netr";$tit="Default";
+	if (preg_match("/^127\.0\.0/",$ip) or preg_match("/^::1/",$ip6) ){$img = "netr";$tit="LocalLoopback";
+	}elseif (preg_match("/^192\.168/",$ip)){$img = "nety";$tit="Private 192.168/16";
+	}elseif (preg_match("/^10\./",$ip)){$img = "netp";$tit="Private 10/8";
+	}elseif (preg_match("/^172\.[1][6-9]/",$ip)){$img = "neto";$tit="Private 172.16/12";
+	}elseif (preg_match("/^172\.[2][0-9]/",$ip)){$img = "neto";$tit="Private 172.16/12";
+	}elseif (preg_match("/^172\.[3][0-1]/",$ip)){$img = "neto";$tit="Private 172.16/12";
+
+	}elseif (preg_match("/^224\.0\.0/",$ip)){$img = "netb";$tit="Local Multicast-224.0.0/24";
+	}elseif (preg_match("/^224\.0\.1/",$ip)){$img = "netb";$tit="Internetwork  Multicast-224.0.1/24";
+	}elseif (preg_match("/^(224|233)/",$ip)){$img = "netb";$tit="AD-HOC Multicast-224~233";
+	}elseif (preg_match("/^232\./",$ip)){$img = "netb";$tit="Source-specific Multicast-232/8";
+	}elseif (preg_match("/^233\./",$ip)){$img = "netb";$tit="GLOP Multicast-233/8";
+	}elseif (preg_match("/^234\./",$ip)){$img = "netb";$tit="Unicast-Prefix Multicast-234/8";
+	}elseif (preg_match("/^239\./",$ip)){$img = "netb";$tit="Public Multicast-239/8";
+
+	}elseif (preg_match("/^fe80/",$ip6)){$img = "nety";$tit="IPv6 Link Local";
+	}elseif (preg_match("/^fc00/",$ip6)){$img = "neto";$tit="IPv6 Unique Local";
+	}elseif (preg_match("/^ff01/",$ip6)){$img = "netb";$tit="IPv6 Interface Local Multicast";
+	}elseif (preg_match("/^ff02/",$ip6)){$img = "netb";$tit="IPv6 Link Local Multicast";
+	}elseif (preg_match("/^2001:0000/",$ip6)){$img = "netp";$tit="IPv6 Teredo";
 
-	if ($nt == "0.0.0.0"){$img = "netr";$tit="Default";
-	}elseif (preg_match("/^127\.0\.0/",$nt)){$img = "netr";$tit="LocalLoopback";
-	}elseif (preg_match("/^192\.168/",$nt)){$img = "neto";$tit="Private-192.168/16";
-	}elseif (preg_match("/^10\./",$nt)){$img = "netp";$tit="Private-10/8";
-	}elseif (preg_match("/^172\.[1][6-9]/",$nt)){$img = "netb";$tit="Private-172.16/12";
-	}elseif (preg_match("/^172\.[2][0-9]/",$nt)){$img = "netb";$tit="Private-172.16/12";
-	}elseif (preg_match("/^172\.[3][0-1]/",$nt)){$img = "netb";$tit="Private-172.16/12";
 	}else{$img = "netg";$tit="Public";}
 	
 	return array("$img.png",$tit);
@@ -428,9 +496,21 @@ function Nettype($nt){
 // Return Smilie based on name
 function Smilie($usr,$s=0){
 	
+	global $stslbl, $cfglbl, $dsclbl, $msglbl;
+
 	$n = strtolower($usr);
-	$si = ( ord($n) + ord(substr($n,1)) + ord(substr($n,-1)) + ord(substr($n,-2)) ) % 70;
-	return "<img src=\"img/smiles/$si.png\"".($s?"width=\"20\"":"")." title=\"Hello, I'm $n\">";
+	if($n == "statc"){
+		return "<img src=\"img/32/conf.png\"".($s?"width=\"20\"":"")." title=\"$cfglbl $stslbl\">";
+	}elseif($n == "statd"){
+		return "<img src=\"img/32/radr.png\"".($s?"width=\"20\"":"")." title=\"$dsclbl $stslbl\">";
+	}elseif($n == "state"){
+		return "<img src=\"img/32/bell.png\"".($s?"width=\"20\"":"")." title=\"$msglbl $stslbl\">";
+	}elseif($n == "stati"){
+		return "<img src=\"img/32/port.png\"".($s?"width=\"20\"":"")." title=\"Interface $stslbl\">";
+	}else{
+		$si = ( ord($n) + ord(substr($n,1)) + ord(substr($n,-1)) + ord(substr($n,-2)) ) % 99;
+		return "<img src=\"img/usr/$si.png\"".($s?"width=\"20\"":"")." title=\"$n\">";
+	}
 }
 
 //===================================================================
@@ -451,34 +531,15 @@ function SkewTime($istr,$var,$days){
 		$repl = "$var=".urlencode(date("m/d/Y H:i",($$var + $s)))."&";
 		$ostr = preg_replace("/$var=[0-9a-z%\+]+(&|$)/i",$repl,$istr);
 	}
+
 	return $ostr;
 }
 
 //===================================================================
-// Return fileicon
-function Fimg($f) {
-	
-	global $hislbl,$fillbl,$imglbl,$cfglbl,$cmdlbl,$mlvl;
-
-	if    (stristr($f,".csv"))				{$i = "list";$t = "CSV $fillbl";}
-	elseif(stristr($f,".def"))				{$i = "geom";$t = "Device Definition";}
-	elseif(stristr($f,".log"))				{$i = "note";$t = "$hislbl";}
-	elseif(stristr($f,".js"))				{$i = "dbmb";$t = "Javascript";}
-	elseif(stristr($f,".php"))				{$i = "php"; $t = "PHP Script";}
-	elseif(stristr($f,".reg"))				{$i = "cog";  $t = "Registry $fillbl";}
-	elseif(stristr($f,".sql"))				{$i = "db";  $t = "DB $fillbl";}
-	elseif(stristr($f,".txt"))				{$i = "abc"; $t = "TXT $fillbl";}
-	elseif(stristr($f,".xml"))				{$i = "dcub";$t = "XML $fillbl";}
-	elseif(preg_match("/\.(cfg|conf)$/i",$f))		{$i = "conf";$t = "$cfglbl";}
-	elseif(preg_match("/\.(exe)$/i",$f))			{$i = "cbox";$t = "$cmdlbl";}
-	elseif(preg_match("/\.(pcm|raw)$/i",$f))		{$i = "bell";$t = "Ringtone";}
-	elseif(preg_match("/\.(bin|loads|img|sbn|swi)$/i",$f))	{$i = "cog"; $t = "Binary Image";}
-	elseif(preg_match("/\.(bmp|gif|jpg|png|svg)$/i",$f))	{$i = "img";$t = "$imglbl";}
-	elseif(preg_match("/\.(zip|tgz|tar|gz|7z|bz2|rar)$/i",$f)){$i = "pkg"; $t = "Archive";}
-	else							{$i = "bbox";$t = "$mlvl[10]";}
-	
-	return "<img src=\"img/16/$i.png\" title=\"$t\">";
+// Return Hex Address
+// echo IP6('fe80::3ee5:a6ff:feca:ea41');
+function IP6($addr) {
+	return bin2hex( inet_pton($addr) );
 }
 
-
 ?>
