@@ -1,5 +1,5 @@
 <html><body>
-<?
+<?php
 $ip = $_SERVER['REMOTE_ADDR'];
 
 echo "PHP ". phpversion();
